@@ -1,12 +1,25 @@
 /*
-    This file is part of the kholidays library.
+  This file is part of the kholidays library.
 
-    SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
-    SPDX-FileCopyrightText: 2004 Allen Winter <winter@kde.org>
-    SPDX-FileCopyrightText: 2008 David Jarvie <djarvie@kde.org>
-    SPDX-FileCopyrightText: 2010 John Layt <john@layt.net>
+  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (c) 2004 Allen Winter <winter@kde.org>
+  Copyright (c) 2008 David Jarvie <djarvie@kde.org>
+  Copyright 2010 John Layt <john@layt.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef KHOLIDAYS_HOLIDAYREGION_H
@@ -14,30 +27,32 @@
 
 #include "kholidays_export.h"
 
-#include <QSharedDataPointer>
-#include <QString>
-#include <QStringList>
+#include <QtCore/QList>
+#include <QtCore/QSharedDataPointer>
+#include <QtCore/QString>
 
 #include "holiday.h"
 
 class QDate;
+class QStringList;
 class QFileInfo;
 
-namespace KHolidays
-{
-class HolidayRegionPrivate;
+namespace KHolidays {
 
-/** Represents a holiday region. */
 class KHOLIDAYS_EXPORT HolidayRegion
 {
-public:
+  public:
     /**
      * Creates a new Holiday Region object for a given standard Region Code.
      *
+     * From 4.5 onwards this constructor requires the new Region Code not the
+     * deprecated Location Code.  If a Location Code is provided the first
+     * match will be created.
+     *
      * @param regionCode The code for the Holiday Region.
      *                   If null or unknown, an empty instance will be created.
      */
-    explicit HolidayRegion(const QString &regionCode = QString());
+    explicit HolidayRegion( const QString &regionCode = QString() );
 
     /**
      * Creates a new Holiday Region object from a given holiday file.
@@ -45,30 +60,39 @@ public:
      *
      * @param regionFile The code for the Holiday Region.
      */
-    explicit HolidayRegion(const QFileInfo &regionFile);
-
-    /** Copy constructor.
-     *  @since 5.77
-     */
-    HolidayRegion(const HolidayRegion &);
-    /** Move constructor.
-     *  @since 5.77
-     */
-    HolidayRegion(HolidayRegion &&);
+    explicit HolidayRegion( const QFileInfo &regionFile );
 
     /**
      * Destroys the holidays object.
      */
     ~HolidayRegion();
 
-    /** Assignment operator.
-     *  @since 5.77
+    /**
+     * @deprecated use regions() instead
+     *
+     *  Return a list of all available location codes which have a holiday definition.
+     *
+     *  One of these can then be passed to the constructor for a new HolidayRegion
+     *  object.
+     *
+     * @see regions()
      */
-    HolidayRegion &operator=(const HolidayRegion &);
-    /** Move Assignment operator.
-     *  @since 5.77
+    static QStringList locations();
+
+    /**
+     * @deprecated use regionCode() or countryCode() instead
+     *
+     * Returns the holiday location.
+     *
+     * The holiday location is a code representing the holiday region.
+     *
+     * @return region code, or null if the instance was constructed with
+     *         an unknown region
+     *
+     * @see regionCode()
+     * @see languageCode()
      */
-    HolidayRegion &operator=(HolidayRegion &&);
+    QString location() const;
 
     /**
      * @since 4.5
@@ -89,15 +113,14 @@ public:
      * Return a reasonable default Holiday Region code
      *
      * If a required country/language is not provided then the current KDE
-     * country/language is used.
+     * country/lanaguage is used.
      *
-     * @param country The country or region to find a default Holiday Region for.
-     *   This can be either an ISO 3166-1 or ISO 3166-2 code.
-     * @param language The language to find a default Holiday Region for
+     * @param country The country to find a default Holiday Region for
+     * @param language The lanaguage to find a default Holiday Region for
      * @return the full region code of the default file
-     * @warning This methods is expensive as it involves parsing all holiday definition files.
      */
-    static QString defaultRegionCode(const QString &country = QString(), const QString &language = QString());
+    static QString defaultRegionCode( const QString &country = QString(),
+                                      const QString &language = QString() );
 
     /**
      * @since 4.5
@@ -119,7 +142,7 @@ public:
      * May be either just a country code ("US" = USA) or may include a regional
      * identifier ("US-CA" = California).  Returns "XX" if not a country.
      *
-     * See https://en.wikipedia.org/wiki/ISO_3166-2
+     * See http://en.wikipedia.org/wiki/ISO_3166-2
      *
      * @return the full region code of the file
      */
@@ -133,14 +156,12 @@ public:
      * May be either just a country code ("US" = USA) or may include a regional
      * identifier ("US-CA" = California).  Returns "XX" if not a country.
      *
-     * See https://en.wikipedia.org/wiki/ISO_3166-2
+     * See http://en.wikipedia.org/wiki/ISO_3166-2
      *
      * @param regionCode The code for the Holiday Region.
      * @return the full region code of the file
-     * @warning This methods is expensive as it involves parsing the corresponding holiday
-     *   definition file. Prefer HolidayRegion::countryCode().
      */
-    static QString countryCode(const QString &regionCode);
+    static QString countryCode( const QString &regionCode );
 
     /**
      * @since 4.5
@@ -164,10 +185,8 @@ public:
      *
      * @param regionCode The code for the Holiday Region.
      * @return the language code of the file
-     * @warning This methods is expensive as it involves parsing the corresponding holiday
-     *   definition file. Prefer HolidayRegion::languageCode().
      */
-    static QString languageCode(const QString &regionCode);
+    static QString languageCode( const QString &regionCode );
 
     /**
      * @since 4.5
@@ -187,7 +206,7 @@ public:
      * @param regionCode The code for the Holiday Region.
      * @return the name of the Holiday Region
      */
-    static QString name(const QString &regionCode);
+    static QString name( const QString &regionCode );
 
     /**
      * @since 4.5
@@ -205,51 +224,34 @@ public:
      *
      * @return the description of the Holiday Region
      */
-    static QString description(const QString &regionCode);
+    static QString description( const QString &regionCode );
 
     /**
-     * @since 5.95
-     *
-     * Returns the list of holidays and astronomical season dates (equinoxes
-     * and solstices) that occur between @p startDate and @p endDate.
-     *
-     */
-    Holiday::List rawHolidaysWithAstroSeasons(const QDate &startDate, const QDate &endDate) const;
-
-    /**
-     * @since 5.97
+     * @since 4.6
      *
      * Returns the list of holidays that occur between @p startDate and @p endDate.
      */
-    Holiday::List rawHolidays(const QDate &startDate, const QDate &endDate) const;
+    Holiday::List holidays( const QDate &startDate, const QDate &endDate, Holiday::MultidayMode multidayMode = Holiday::MultidayHolidaysAsMultipleEvents ) const;
 
     /**
-     * @since 5.95
+     * @since 4.6
      *
-     * Returns the list of holidays and astronomical season dates (equinoxes
-     * and solstices) that occur on a @p date.
+     * Returns the list of holidays that occur on a @p date.
      */
-    Holiday::List rawHolidaysWithAstroSeasons(const QDate &date) const;
+    Holiday::List holidays( const QDate &date, Holiday::MultidayMode multidayMode = Holiday::MultidayHolidaysAsMultipleEvents ) const;
 
     /**
-     * @since 5.95
+     * @since 4.6
      *
-     * Returns the list of holidays and astronomical season dates (equinoxes
-     * and solstices) that occur in a Gregorian calendar year @p calendarYear.
+     * Returns the list of holidays that occur in a calendar year @p calendarYear.
      */
-    Holiday::List rawHolidaysWithAstroSeasons(int calendarYear) const;
-
-    /**
-     * @since 5.95
-     *
-     * Returns the list of holidays that occur between @p startDate and @p endDate and with @p category.
-     */
-    Holiday::List rawHolidays(const QDate &startDate, const QDate &endDate, const QString &category) const;
+    Holiday::List holidays( int calendarYear, const QString &calendarType,
+                            Holiday::MultidayMode multidayMode = Holiday::MultidayHolidaysAsMultipleEvents) const;
 
     /**
      * Checks whether there is any holiday defined for a @p date.
      */
-    bool isHoliday(const QDate &date) const;
+    bool isHoliday( const QDate &date ) const;
 
     /**
      * Returns whether the instance contains any holiday data.
@@ -261,10 +263,13 @@ public:
      *
      * Returns whether the Region Code is valid.
      */
-    static bool isValid(const QString &regionCode);
+    static bool isValid( const QString &regionCode );
 
-private:
-    QExplicitlySharedDataPointer<HolidayRegionPrivate> d;
+  private:
+    Q_DISABLE_COPY( HolidayRegion )
+
+    class Private;
+    Private *const d;
 };
 
 }
